@@ -1,6 +1,6 @@
 """Export resources."""
 
 from .config import DriverConfigError
-from .fields import FieldCastError, FieldTypeError, FieldValueError
+from .fields import FieldCastError, FieldTypeError
 from .queries import BuilderError, DriverExecutionError, QueryError
 from .serialization import SerializationError
